<?php

$lan = array(

'listofadministrators' => 'List of Administrators',
'Add a new Administrator' => 'Add a new Administrator',
'No Access' => 'No Access',
'Error adding new admin' => 'Error adding new admin',
'strAccessExplain' => '<hr/>
<p class="information">Set permissions to view pages in the system:</p>
<ul>
<li>All: admin has access to page without restrictions</li>
<li>View: admin can view content of pages, but not change anything. This currently only work
for the "user", "users" and "members" pages.</li>
<li>None: admin cannot see this page</li>
<li>Owner: admin can see this page, but only see the content of the lists they own</li>
</ul>
<p class="information">Note: Admin Password must be at least 4 characters long</p>
',
'Edit Administrator' => 'Edit Administrator',
'Admin Details' => 'Admin Details',
'Login Name' => 'Login Name',
'Normalised loginname' => 'Normalised loginname',
'Time Created' => 'Time Created',
'Time modified' => 'Time modified',
'Modified by' => 'Modified by',
'Is this user Super Admin?' => 'Is this user Super Admin?',
'Current set of permissions made default' => 'Current set of permissions made default',
'OK' => 'OK',
'Login Name (max 25 chars)' => 'Login Name (max 25 chars)',
'Access Details' => 'Access Details',
'Access Privileges' => 'Access Privileges',
'Page' => 'Page',
'Set these permissions as default' => 'Set these permissions as default',
'Reset to Default' => 'Reset to Default',
'all' => 'all',
'Failed, you cannot delete yourself' => 'Failed, you cannot delete yourself',
'Update it?' => 'Update it?',
'Remind it?' => 'Remind it?',
);
?>